# frozen_string_literal: true
module SearchDownloadHelper
  include ComplexFilterHelper

  def prepare_download_file_for_search_results
    return redirect_to download_search_results_catalog_path(q: params[:q], shell_file_name: shell_file_name, format: :sh) if has_shell_file? 
    params[:per_page] = 2_000_000_000
    (@response, @document_list) = search_results(params)

    work_class_names = ::Hyrax.config.curation_concerns.map(&:to_s)
    doc_ids_and_source_identifiers = @document_list.map{|doc| [doc.id, doc.source.first] if work_class_names.include?(doc._source[:has_model_ssim][0])}.compact
    doc_ids = doc_ids_and_source_identifiers.to_h.keys
    doc_source_identifiers = doc_ids_and_source_identifiers.to_h.values

    Hyrax::DownloadSearchJob.perform_later(current_user, doc_ids, shell_file_path, download_link, doc_source_identifiers, fetch_crc_filter_params(params), params[:skip_filters] == 'true')

    flash[:alert] = I18n.t('hyrax.notifications.preparing_download.message')
    redirect_to request.referrer
  end

  def send_shell_file
    return head :not_found unless has_shell_file?

    send_file shell_file_path, type: 'application/x-sh', disposition: 'inline'
  end

  def has_shell_file?
    File.exist?(shell_file_path)
  end

  def shell_file_path
    @shell_file_path ||= File.join("/shared/downloads", "users/#{shell_file_name}")
  end

  def shell_file_name
    @shell_file_name ||= params[:shell_file_name] || "#{Time.now.strftime('%Y%m%d%H%M%S')}.sh"
  end

  def download_link
    ActionController::Base.helpers.link_to :here, download_search_results_catalog_path(q: params[:q], shell_file_name: shell_file_name)
  end
end
